==> sdx-2.4-src.zip: sdx-2.4/src/java/fr/gouv/culture/oai/SynchronizedOAIObjectImpl.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.oai;

import fr.gouv.culture.oai.util.OAIUtilities;
import fr.gouv.culture.util.apache.cocoon.xml.AbstractSynchronizedXMLPipe;
import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.DefaultContext;
import org.apache.avalon.framework.logger.Logger;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.AttributesImpl;

public abstract class SynchronizedOAIObjectImpl extends AbstractSynchronizedXMLPipe implements OAIObject {

    protected Logger logger = null;
    protected DefaultContext _context = null;

    public void enableLogging(Logger logger) {
        this.logger = logger;
    }

    public void contextualize(Context context) throws ContextException {
        _context = new DefaultContext(context);
    }

    protected DefaultContext getContext() {
        return _context;
    }

    protected void sendElement(String uri, String localName, String qName, Attributes atts, String elemContent) throws SAXException {
        this.startElement(uri, localName, qName, atts);
        this.sendElementContent(elemContent);
        super.endElement(uri, localName, qName);
    }


    public void startElement(String uri, String localName, String qName, Attributes atts) throws SAXException {
        if (atts == null) atts = new AttributesImpl();
        super.startElement(uri, localName, qName, atts);

    }

    protected void sendElementContent(String content) throws SAXException {
        if (OAIUtilities.checkString(content)) {
            char[] chars = content.toCharArray();
            super.characters(chars, 0, chars.length);
        }

    }

}

==> sdx-2.4.1.3-src.zip: sdx-2.4.1.3/src/java/fr/gouv/culture/oai/SynchronizedOAIObjectImpl.java <==
/*
Copyright (C) 2000-2010  Ministere de la culture et de la communication (France), AJLSM
See LICENCE file
*/
package fr.gouv.culture.oai;

import fr.gouv.culture.oai.util.OAIUtilities;
import fr.gouv.culture.util.apache.cocoon.xml.AbstractSynchronizedXMLPipe;
import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.DefaultContext;
import org.apache.avalon.framework.logger.Logger;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.AttributesImpl;

public abstract class SynchronizedOAIObjectImpl extends AbstractSynchronizedXMLPipe implements OAIObject {

    protected Logger logger = null;
    protected DefaultContext _context = null;

    public void enableLogging(Logger logger) {
        this.logger = logger.getChildLogger("oai");
    }

    public void contextualize(Context context) throws ContextException {
        _context = new DefaultContext(context);
    }

    protected DefaultContext getContext() {
        return _context;
    }

    protected void sendElement(String uri, String localName, String qName, Attributes atts, String elemContent) throws SAXException {
        this.startElement(uri, localName, qName, atts);
        this.sendElementContent(elemContent);
        super.endElement(uri, localName, qName);
    }


    public void startElement(String uri, String localName, String qName, Attributes atts) throws SAXException {
        if (atts == null) atts = new AttributesImpl();
        super.startElement(uri, localName, qName, atts);

    }

    protected void sendElementContent(String content) throws SAXException {
        if (OAIUtilities.checkString(content)) {
            char[] chars = content.toCharArray();
            super.characters(chars, 0, chars.length);
        }

    }

}
